@@ -20,15 +20,27 @@
 
 #include "componentchooserfilemanager.h"
 #include <kbuildsycocaprogressdialog.h>
-#include <QDebug>
 #include <kprocess.h>
 #include <kmimetypetrader.h>
 #include <kopenwithdialog.h>
 #include <kconfiggroup.h>
 #include <QStandardPaths>
-#include <QFileInfo>
+#include <KSharedConfig>
 
-#include "../migrationlib/kdelibs4config.h"
+namespace  {
+
+QRadioButton *findDolphinRadio(const QList<QRadioButton *> &radioButtons)
+{
+    auto it = std::find_if(radioButtons.begin(), radioButtons.end(), [=](QRadioButton *radio) {
+        return radio->property("storageId") == QStringLiteral("org.kde.dolphin.desktop");
+    });
+    if (it == radioButtons.end()) {
+        return nullptr;
+    }
+    return *it;
+}
+
+}
 
 CfgFileManager::CfgFileManager(QWidget *parent)
     : QWidget(parent), Ui::FileManagerConfig_UI(),CfgPlugin()
@@ -48,6 +60,18 @@ void CfgFileManager::configChanged()
 void CfgFileManager::defaults()
 {
     load(nullptr);
+
+    const auto radio = ::findDolphinRadio(mDynamicRadioButtons);
+    if (radio) {
+        radio->setChecked(true);
+    }
+}
+
+bool CfgFileManager::isDefaults() const
+{
+    const auto dolphinRadio = ::findDolphinRadio(mDynamicRadioButtons);
+    // When dolphin is not present, we can't assume any default value
+    return !dolphinRadio || dolphinRadio->isChecked();
 }
 
 static KService::List appOffers()
@@ -56,13 +80,12 @@ static KService::List appOffers()
 }
 
 void CfgFileManager::load(KConfig *) {
-    qDeleteAll(mDynamicWidgets);
-    mDynamicWidgets.clear();
+    qDeleteAll(mDynamicRadioButtons);
+    mDynamicRadioButtons.clear();
     const KService::List apps = appOffers();
     bool first = true;
-    Q_FOREACH(const KService::Ptr& service, apps)
-    {
-        QRadioButton* button = new QRadioButton(service->name(), this);
+    for (const KService::Ptr &service : apps) {
+        QRadioButton *button = new QRadioButton(service->name(), this);
         connect(button, &QRadioButton::toggled, this, &CfgFileManager::configChanged);
         button->setProperty("storageId", service->storageId());
         radioLayout->addWidget(button);
@@ -70,7 +93,7 @@ void CfgFileManager::load(KConfig *) {
             button->setChecked(true);
             first = false;
         }
-        mDynamicWidgets << button;
+        mDynamicRadioButtons << button;
     }
 
     emit changed(false);
@@ -78,18 +101,16 @@ void CfgFileManager::load(KConfig *) {
 
 static const char s_DefaultApplications[] = "Default Applications";
 static const char s_AddedAssociations[] = "Added Associations";
-static const char s_RemovedAssociations[] = "Removed Associations";
 
 void CfgFileManager::save(KConfig *)
 {
     QString storageId;
-    Q_FOREACH(QRadioButton* button, qFindChildren<QRadioButton*>(this)) {
+    for (QRadioButton *button : qAsConst(mDynamicRadioButtons)) {
         if (button->isChecked()) {
             storageId = button->property("storageId").toString();
         }
     }
 
-    qDebug() << storageId;
     if (!storageId.isEmpty()) {
         // This is taken from filetypes/mimetypedata.cpp
         KSharedConfig::Ptr profile = KSharedConfig::openConfig(QStringLiteral("mimeapps.list"), KConfig::NoGlobals, QStandardPaths::GenericConfigLocation);
@@ -106,25 +127,8 @@ void CfgFileManager::save(KConfig *)
         KConfigGroup defaultApp(profile, s_DefaultApplications);
         defaultApp.writeXdgListEntry(mime, QStringList(storageId));
 
-        Kdelibs4SharedConfig::syncConfigGroup(QLatin1String("Added Associations"), QStringLiteral("mimeapps.list"));
-
         profile->sync();
 
-        // Clean out any kde-mimeapps.list which would take precedence any cancel our changes.
-        // (also taken from filetypes/mimetypedata.cpp)
-        const QString desktops = QString::fromLocal8Bit(qgetenv("XDG_CURRENT_DESKTOP"));
-        foreach (const QString &desktop, desktops.split(":", QString::SkipEmptyParts)) {
-            const QString file = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation)
-                + QLatin1Char('/') + desktop.toLower() + QLatin1String("-mimeapps.list");
-            if (QFileInfo::exists(file)) {
-                qDebug() << "Cleaning up" << file;
-                KConfig conf(file, KConfig::NoGlobals);
-                KConfigGroup(&conf, s_DefaultApplications).deleteEntry(mime);
-                KConfigGroup(&conf, s_AddedAssociations).deleteEntry(mime);
-                KConfigGroup(&conf, s_RemovedAssociations).deleteEntry(mime);
-            }
-        }
-
         KBuildSycocaProgressDialog::rebuildKSycoca(this);
     }
 
